@@ -59,7 +59,7 @@ sub to_xhtml {
     my $self = shift;
     my $parser = shift;
     my $el = $parser->mk_element('code')->insert_to( $parser->mk_element('pre') );
-    $el->add_content( $self->_make_elements(@_) );
+    $el->add_content( $self->_make_elements($parser,@_) );
 }
 
 =head2 to_docbook
@@ -102,8 +102,8 @@ sub _html_escape {
     $txt   =~ s/&/&amp;/g;
     $txt   =~ s/</&lt;/g;
     $txt   =~ s/>/&gt;/g;
-    $txt   =~ s/"/&quot;/g;
-    $txt   =~ s/'/&apos;/g;
+#    $txt   =~ s/"/&quot;/g;
+#    $txt   =~ s/'/&apos;/g;
     $txt
 }
 1;
