@@ -138,34 +138,22 @@ sub b06_like_attribute_array : Test {
       }, ":like['test3','test4']>";
 }
 
-sub b07_allow_attribute: Test  {
-    return "skip";
+sub b07_check_allow_parent_on: Test(2)  {
     my $t = shift;
-    my $x = $t->parse_to_xml(<<T,);
-=begin pod
-=for para :allow<B>
-B<Test more text>I<test>
-=end pod
-T
-    diag $x;exit;
     my $c = new Perl6::Pod::Parser::Context;
-    $c->config->{'test1'} = ":w1 :like<test4>";
+    $c->custom->{'_check_allow_parent_on_'} = 1;
+    $c->{_allow_context}->{I} = 1;
+    $c->{_allow_context}->{B} = 1;
     $c->config->{'test2'} = ":w2(2) :w3(4) :like<test3>";
     $c->config->{'test3'} = ":w3(3) :o1(4) :w4(2)";
     $c->config->{'test4'} = ":w4";
     my $b = new Perl6::Pod::Block::
-      name    => 'test1',
+      name    => 'S',
       context => $c,
-      options => ":o1('3') :like['test3','test4']>";
+      options => ":allow<B>";
     my $tattr = $b->get_attr;
-    delete $tattr->{like};
-    is_deeply $tattr,
-      {
-        'w4' => 2,
-        'o1' => '3',
-        'w3' => 3,
-        'w1' => 1
-      }, ":like['test3','test4']>";
+     ok  $b->context->custom->{_check_allow_parent_on_}, 'check $b->context->custom->{_check_allow_parent_on_}';
+    is join (""=> @{$b->parse_str("N<s>")}), 'N<s>';
 }
 
 
