@@ -64,18 +64,26 @@ q#<chapter><para><code>test &gt; &amp;</code>
 
 sub t05_extra : Test {
     my $t = shift;
+
     my $x = $t->parse_to_xhtml( <<T);
 =para
 C<< test > & E<nbsp> >>
 T
-    ok $x =~ /&nbsp;/;
-#    diag $x;
-#    $t->is_deeply_xml( $x,
-#q#<chapter><para><code>test &gt; &amp;</code>
-#</para></chapter>#
-#   );
+    ok $x =~ /E&lt;nbsp&gt;/;
 }
 
 
+sub t06_allow_for_C : Test {
+    my $t = shift;
+    my $x = $t->parse_to_xhtml( <<T);
+=config C<> :allow<I E>
+=para
+sdssd C<E<nbsp>>
+T
+    ok $x =~ m{<code>&nbsp;</code>};
+}
+
+
+
 1;
 
